@@ -1,4 +1,4 @@
-﻿//
+//
 // Authors:
 //	Christian Hergert  <chris@mosaix.net>
 //	Daniel Morgan <danielmorgan@verizon.net>
@@ -36,7 +36,9 @@ namespace MonoDevelop.Database.Sql.MySql
 {
 	public class MySqlConnectionProvider : AbstractConnectionProvider
 	{
-		public override IPooledDbConnection CreateConnection (IConnectionPool pool, DatabaseConnectionSettings settings, out string error)
+		public override IPooledDbConnection CreateConnection (IConnectionPool pool, 
+		                                                      DatabaseConnectionSettings settings, 
+		                                                      out string error)
 		{
 			string connStr = null;
 			try {	
@@ -45,8 +47,13 @@ namespace MonoDevelop.Database.Sql.MySql
 				} else {
 					//"Server=Server;Port=1234;Database=Test;Uid=UserName;Pwd=asdasd;"
 					//Default port is 3306. Enter value -1 to use a named pipe connection. 
-					connStr = String.Format ("Server={0};Port={1};Database={2};Uid={3};Pwd={4};",
-						settings.Server, settings.Port, settings.Database, settings.Username, settings.Password);
+					if (settings.Port > 0)
+						connStr = String.Format ("Server={0};Port={1};Database={2};Uid={3};Pwd={4};",
+							settings.Server, settings.Port, settings.Database, settings.Username, settings.Password);
+					else
+						connStr = String.Format ("Server={0};Database={2};Uid={3};Pwd={3};",
+							settings.Server, settings.Database, settings.Username, settings.Password);
+						
 				}
 				connStr = SetConnectionStringParameter (connStr, String.Empty, "Pooling", "false");
 				MySqlConnection connection = new MySqlConnection (connStr);
